@@ -6,12 +6,18 @@ import abc
 from dataclasses import dataclass
 from typing import AsyncGenerator, Iterable, Union
 
-from asn1crypto import x509, ocsp, crl, cms
+from asn1crypto import cms, crl, ocsp, x509
+
+from pyhanko_certvalidator.authority import Authority
 from pyhanko_certvalidator.version import __version__
 
 __all__ = [
-    'OCSPFetcher', 'CRLFetcher', 'CertificateFetcher',
-    'Fetchers', 'FetcherBackend', 'DEFAULT_USER_AGENT'
+    'OCSPFetcher',
+    'CRLFetcher',
+    'CertificateFetcher',
+    'Fetchers',
+    'FetcherBackend',
+    'DEFAULT_USER_AGENT',
 ]
 
 DEFAULT_USER_AGENT = 'pyhanko_certvalidator %s' % __version__
@@ -20,20 +26,18 @@ DEFAULT_USER_AGENT = 'pyhanko_certvalidator %s' % __version__
 class OCSPFetcher(abc.ABC):
     """Utility interface to fetch and cache OCSP responses."""
 
-    async def fetch(self,
-                    cert: Union[x509.Certificate, cms.AttributeCertificateV2],
-                    issuer: x509.Certificate) -> ocsp.OCSPResponse:
+    async def fetch(
+        self,
+        cert: Union[x509.Certificate, cms.AttributeCertificateV2],
+        authority: Authority,
+    ) -> ocsp.OCSPResponse:
         """
         Fetch an OCSP response for a certificate.
 
         :param cert:
             The certificate for which an OCSP response has to be fetched.
-        :param issuer:
-            The relevant issuer's certificate.
-
-            .. note::
-                This parameter is used to compute the hash of the issuer's
-                public key that is sent with the OCSP request.
+        :param authority:
+            The issuing authority.
         :raises:
             OCSPFetchError - Raised if an OCSP response could not be obtained.
         :return:
@@ -48,9 +52,8 @@ class OCSPFetcher(abc.ABC):
         raise NotImplementedError
 
     def fetched_responses_for_cert(
-            self,
-            cert: Union[x509.Certificate, cms.AttributeCertificateV2]) \
-            -> Iterable[ocsp.OCSPResponse]:
+        self, cert: Union[x509.Certificate, cms.AttributeCertificateV2]
+    ) -> Iterable[ocsp.OCSPResponse]:
         """
         Return all responses fetched by this OCSP fetcher that are relevant
         to determine the revocation status of the given certificate.
@@ -61,9 +64,12 @@ class OCSPFetcher(abc.ABC):
 class CRLFetcher(abc.ABC):
     """Utility interface to fetch and cache CRLs."""
 
-    async def fetch(self,
-                    cert: Union[x509.Certificate, cms.AttributeCertificateV2],
-                    *, use_deltas=None) -> Iterable[crl.CertificateList]:
+    async def fetch(
+        self,
+        cert: Union[x509.Certificate, cms.AttributeCertificateV2],
+        *,
+        use_deltas=None
+    ) -> Iterable[crl.CertificateList]:
         """
         Fetches the CRLs for a certificate.
 
@@ -93,9 +99,8 @@ class CRLFetcher(abc.ABC):
         raise NotImplementedError
 
     def fetched_crls_for_cert(
-            self,
-            cert: Union[x509.Certificate, cms.AttributeCertificateV2]) \
-            -> Iterable[crl.CertificateList]:
+        self, cert: Union[x509.Certificate, cms.AttributeCertificateV2]
+    ) -> Iterable[crl.CertificateList]:
         """
         Return all relevant fetched CRLs for the given certificate
         :param cert:
@@ -112,9 +117,8 @@ class CertificateFetcher(abc.ABC):
     """Utility interface to fetch and cache certificates."""
 
     def fetch_cert_issuers(
-            self,
-            cert: Union[x509.Certificate, cms.AttributeCertificateV2]) \
-            -> AsyncGenerator[x509.Certificate, None]:
+        self, cert: Union[x509.Certificate, cms.AttributeCertificateV2]
+    ) -> AsyncGenerator[x509.Certificate, None]:
         """
         Fetches certificates from the authority information access extension of
         a certificate.
@@ -131,8 +135,9 @@ class CertificateFetcher(abc.ABC):
         """
         raise NotImplementedError
 
-    def fetch_crl_issuers(self, certificate_list) \
-            -> AsyncGenerator[x509.Certificate, None]:
+    def fetch_crl_issuers(
+        self, certificate_list
+    ) -> AsyncGenerator[x509.Certificate, None]:
         """
         Fetches certificates from the authority information access extension of
         an asn1crypto.crl.CertificateList.
