@@ -1,24 +1,31 @@
+import logging
 from typing import Iterable, Union
 
-import logging
 import requests
-from asn1crypto import ocsp, x509, cms
+from asn1crypto import cms, ocsp, x509
 
 from ... import errors
+from ...authority import Authority
+from ...util import get_ocsp_urls, issuer_serial
 from ..api import OCSPFetcher
-from .util import RequestsFetcherMixin
 from ..common_utils import (
-    process_ocsp_response_data, format_ocsp_request, ocsp_job_get_earliest
+    format_ocsp_request,
+    ocsp_job_get_earliest,
+    process_ocsp_response_data,
 )
-from ...util import issuer_serial, get_ocsp_urls
+from .util import RequestsFetcherMixin
 
 logger = logging.getLogger(__name__)
 
 
 class RequestsOCSPFetcher(OCSPFetcher, RequestsFetcherMixin):
-
-    def __init__(self, user_agent=None, per_request_timeout=10,
-                 certid_hash_algo='sha1', request_nonces=True):
+    def __init__(
+        self,
+        user_agent=None,
+        per_request_timeout=10,
+        certid_hash_algo='sha1',
+        request_nonces=True,
+    ):
         super().__init__(user_agent, per_request_timeout)
         if certid_hash_algo not in ('sha1', 'sha256'):
             raise ValueError(
@@ -28,36 +35,44 @@ class RequestsOCSPFetcher(OCSPFetcher, RequestsFetcherMixin):
         self.certid_hash_algo = certid_hash_algo
         self.request_nonces = request_nonces
 
-    async def fetch(self,
-                    cert: Union[x509.Certificate, cms.AttributeCertificateV2],
-                    issuer: x509.Certificate) -> ocsp.OCSPResponse:
+    async def fetch(
+        self,
+        cert: Union[x509.Certificate, cms.AttributeCertificateV2],
+        authority: Authority,
+    ) -> ocsp.OCSPResponse:
 
-        tag = (issuer_serial(cert), issuer.issuer_serial)
-        return await self._perform_fetch(tag, lambda: self._fetch(cert, issuer))
+        tag = (issuer_serial(cert), authority.hashable)
+        return await self._perform_fetch(
+            tag, lambda: self._fetch(cert, authority)
+        )
 
     async def _fetch_single(self, ocsp_url, ocsp_request):
         try:
             logger.info(f"Requesting OCSP response from {ocsp_url}...")
             response = await self._post(
-                url=ocsp_url, data=ocsp_request.dump(),
+                url=ocsp_url,
+                data=ocsp_request.dump(),
                 content_type='application/ocsp-request',
-                acceptable_content_types=('application/ocsp-response',)
+                acceptable_content_types=('application/ocsp-response',),
             )
             return process_ocsp_response_data(
-                response.content, ocsp_request=ocsp_request,
-                ocsp_url=ocsp_url
+                response.content, ocsp_request=ocsp_request, ocsp_url=ocsp_url
             )
         except (ValueError, requests.RequestException) as e:
             raise errors.OCSPFetchError(
                 f"Failed to fetch OCSP response from {ocsp_url}",
             ) from e
 
-    async def _fetch(self,
-                     cert: Union[x509.Certificate, cms.AttributeCertificateV2],
-                     issuer: x509.Certificate):
+    async def _fetch(
+        self,
+        cert: Union[x509.Certificate, cms.AttributeCertificateV2],
+        authority: Authority,
+    ):
         ocsp_request = format_ocsp_request(
-            cert, issuer, certid_hash_algo=self.certid_hash_algo,
-            request_nonces=self.request_nonces
+            cert,
+            authority,
+            certid_hash_algo=self.certid_hash_algo,
+            request_nonces=self.request_nonces,
         )
         ocsp_urls = get_ocsp_urls(cert)
         if not ocsp_urls:
@@ -73,8 +88,7 @@ class RequestsOCSPFetcher(OCSPFetcher, RequestsFetcherMixin):
             f"{';'.join(ocsp_urls)}..."
         )
         ocsp_response = await ocsp_job_get_earliest(
-            self._fetch_single(ocsp_url, ocsp_request)
-            for ocsp_url in ocsp_urls
+            self._fetch_single(ocsp_url, ocsp_request) for ocsp_url in ocsp_urls
         )
         return ocsp_response
 
@@ -82,10 +96,11 @@ class RequestsOCSPFetcher(OCSPFetcher, RequestsFetcherMixin):
         return self.get_results()
 
     def fetched_responses_for_cert(
-            self, cert: Union[x509.Certificate, cms.AttributeCertificateV2]) \
-            -> Iterable[ocsp.OCSPResponse]:
+        self, cert: Union[x509.Certificate, cms.AttributeCertificateV2]
+    ) -> Iterable[ocsp.OCSPResponse]:
         target_is = issuer_serial(cert)
         return {
-            resp for (subj_is, _), resp in self._iter_results()
+            resp
+            for (subj_is, _), resp in self._iter_results()
             if subj_is == target_is
         }
